@@ -50,6 +50,18 @@ def contains(array, *args):
     return False
 
 
+def unique(array):
+    """
+    Remove any duplicate items from the given array
+    :param array:
+    :param args:
+    :return: true if at least one item exists, false otherwise
+    """
+
+    indexed = set()
+    return [x for x in array if x not in indexed and (indexed.add(x) or True)]
+
+
 def copy(entries):
     result = list()
 
